
#ifndef __GIBBER_NAMESPACES_H__
#define __GIBBER_NAMESPACES_H__

#define GIBBER_XMPP_NS_STREAM \
  (const gchar *)"http://etherx.jabber.org/streams"

#define GIBBER_XMPP_NS_TLS \
  (const gchar *)"urn:ietf:params:xml:ns:xmpp-tls"

#define GIBBER_XMPP_NS_SASL_AUTH \
  (const gchar *)"urn:ietf:params:xml:ns:xmpp-sasl"

#define GIBBER_XMPP_NS_XHTML_IM \
  (const gchar *)"http://jabber.org/protocol/xhtml-im"

#define GIBBER_XMPP_NS_IBB \
  (const gchar *)"http://jabber.org/protocol/ibb"

#define GIBBER_XMPP_NS_AMP \
  (const gchar *)"http://jabber.org/protocol/amp"

#define GIBBER_W3C_NS_XHTML \
  (const gchar *)"http://www.w3.org/1999/xhtml"

#define GIBBER_TELEPATHY_NS_TUBES \
  (const gchar *)"http://telepathy.freedesktop.org/xmpp/tubes"

#define GIBBER_TELEPATHY_NS_OLPC_ACTIVITY_PROPS \
  (const gchar *)"http://laptop.org/xmpp/activity-properties"

#define GIBBER_XMPP_NS_SI \
  (const gchar *)"http://jabber.org/protocol/si"

#define GIBBER_XMPP_NS_FEATURENEG \
  (const gchar *)"http://jabber.org/protocol/feature-neg"

#define GIBBER_XMPP_NS_DATA \
  (const gchar *)"jabber:x:data"

#define GIBBER_XMPP_NS_EVENT \
  (const gchar *)"jabber:x:event"

#define GIBBER_XMPP_NS_STANZAS \
  (const gchar *)"urn:ietf:params:xml:ns:xmpp-stanzas"

#define GIBBER_XMPP_NS_OOB \
  (const gchar *)"jabber:iq:oob"

#define GIBBER_XMPP_NS_JINGLE_ERRORS \
  (const gchar *)"http://jabber.org/protocol/jingle#errors"

#define GIBBER_TELEPATHY_NS_CLIQUE \
  (const gchar *)"http://telepathy.freedesktop.org/xmpp/clique"

#define GIBBER_XMPP_NS_OOB \
  (const gchar *)"jabber:iq:oob"

#define GIBBER_XMPP_NS_STANZAS \
  (const gchar *)"urn:ietf:params:xml:ns:xmpp-stanzas"

#endif /* #ifndef __GIBBER_NAMESPACES_H__ */
